@@ -5,7 +5,6 @@ import re
 import sys
 from collections import namedtuple
 
-import jsonschema
 import pytest
 
 from cloudinit import subp
@@ -28,6 +27,11 @@ from cloudinit.util import Version
 from tests.unittests.helpers import does_not_raise, mock, skipUnlessJsonSchema
 from tests.unittests.util import get_cloud
 
+try:
+    import jsonschema
+except ImportError:
+    jsonschema = None  # type: ignore
+
 # Module path used in mocks
 MPATH = "cloudinit.config.cc_ubuntu_pro"
 
